;; Generated package description from xref.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "xref" "1.7.0.0.20260313.230302" "Cross-referencing commands" '((emacs "26.1")) :commit "44fa418987ea7b28d8931497b9c389f4e2ff544d" :url "https://elpa.gnu.org/packages/xref.html")
